Threshold stability plots
autoplot.elife_tstab(object, ...)# S3 method for elife_tstab
plot(
x,
plot.type = c("base", "ggplot"),
which.plot = c("scale", "shape"),
plot = TRUE,
...
)
This S3 method is used to create plots; it only returns a list of graphs if plot.type="ggplot"
object of class elife_tstab, representing parameter estimates to draw threshold stability plots
additional arguments, currently ignored by the function.
an object of class elife_tstab containing
the fitted parameters as a function of threshold
string, one of base for base R or ggplot
vector of string indicating the plots, among pp for probability-probability plot, qq for quantile-quantile plot, erp for empirically rescaled plot (only for censored data), exp for standard exponential quantile-quantile plot or tmd for Tukey's mean difference plot, which is a variant of the Q-Q plot in which we map the pair \((x,y)\) is mapped to ((x+y)/2,y-x) are detrended, dens and cdf return the empirical distribution function with the fitted parametric density or distribution function curve superimposed.
logical; if TRUE, creates a plot when plot.type="ggplot". Useful for returning ggplot objects without printing the graphs