| french | R Documentation |
This data frame contains information about 9853 French semi-supercentenarian, part of the International Database on Longevity (IDL). All supercentenarian records were validated, but only a random sample of semi-supercentenarians were validated. Lifetimes are interval truncated; only people above 110 born after 1978 and people above 105 born after 1987 are included.
french
A data frame with 9853 rows and 6 variables:
survival time (in days)
birth date (Date)
death date (Date) if the person
is alive at the end of the sampling
minimum age (in days); the maximum of 38350 days (approximately 105 years) or the number of days reached on January 1st 1978 (supercentenarian) or 1987 (semisupercentenarian)
maximum age (in days) an individual could have reached by the end of 2017
factor indicating gender of individual,
either female or male
International Database on Longevity (IDL), 2021. Hosted by the French Institute for Demographic Studies (Ined) at https://www.supercentenarians.org/en/. The IDL data are licensed under CC BY 4.0 License; please refer to the IDL database to download the latest available data.
International Database on Longevity (2021). French Institute for Demographic Studies (Ined) (host).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.